### Name: powcor.shrink
### Title: Fast Computation of the Power of the Shrinkage Correlation
###   Matrix
### Aliases: powcor.shrink
### Keywords: multivariate

### ** Examples

## Not run: 
##D 
##D # load corpcor library
##D library("corpcor")
##D 
##D # generate data matrix
##D p = 2000
##D n = 10
##D X = matrix(rnorm(n*p), nrow = n, ncol = p)
##D 
##D lambda = 0.23  # some arbitrary lambda
##D 
##D ### computing the inverse ###
##D # slow
##D system.time(
##D   (W1 = solve(cor.shrink(X, lambda=lambda)))
##D )
##D 
##D # very fast
##D system.time(
##D   (W2 = powcor.shrink(X, alpha=-1, lambda=lambda))
##D )
##D 
##D # no difference
##D sum((W1-W2)^2)
##D 
##D ### computing the square root ###
##D 
##D system.time(
##D   (W1 = mpower(cor.shrink(X, lambda=lambda), alpha=0.5))
##D )
##D 
##D # very fast
##D system.time(
##D   (W2 = powcor.shrink(X, alpha=0.5, lambda=lambda))
##D )
##D 
##D # no difference
##D sum((W1-W2)^2)
##D 
##D ### computing an arbitrary power (alpha=1.23) ###
##D 
##D system.time(
##D   (W1 = mpower(cor.shrink(X, lambda=lambda), alpha=1.23))
##D )
##D 
##D # very fast
##D system.time(
##D   (W2 = powcor.shrink(X, alpha=1.23, lambda=lambda))
##D )
##D 
##D # no difference
##D sum((W1-W2)^2)
##D 
## End(Not run)



